==> navigine_sdk-1.2.1%2B3.tar.gz: android/src/main/java/com/navigine/navigine/Convert.java <==
package com.navigine.navigine;

import android.graphics.Bitmap;

import com.navigine.naviginesdk.Beacon;
import com.navigine.naviginesdk.DeviceInfo;
import com.navigine.naviginesdk.Location;
import com.navigine.naviginesdk.LocationPoint;
import com.navigine.naviginesdk.MeasureObject;
import com.navigine.naviginesdk.RouteEvent;
import com.navigine.naviginesdk.RoutePath;
import com.navigine.naviginesdk.SubLocation;
import com.navigine.naviginesdk.Venue;
import com.navigine.naviginesdk.Zone;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

class Convert {

    static Object deviceInfoToObject(DeviceInfo deviceInfo) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("azimuth", deviceInfo.azimuth);
        data.put("errorCode", deviceInfo.errorCode);
        data.put("id", deviceInfo.id);
        data.put("location", deviceInfo.location);
        data.put("r", deviceInfo.r);
        data.put("stepCount", deviceInfo.stepCount);
        data.put("subLocation", deviceInfo.subLocation);
        data.put("stepLength", deviceInfo.stepLength);
        data.put("time", deviceInfo.time);
        data.put("x", deviceInfo.x);
        data.put("y", deviceInfo.y);

        ArrayList<Object> zones = new ArrayList<>();
        for (int i = 0; i < deviceInfo.zones.size(); i++) {
            zones.add(zoneToObject(deviceInfo.zones.get(i)));
        }
        data.put("zones", zones);

        ArrayList<Object> paths = new ArrayList<>();
        for (int i = 0; i < deviceInfo.paths.size(); i++) {
            paths.add(routePathToObject(deviceInfo.paths.get(i)));
        }
        data.put("paths", paths);

        return data;
    }

    static Object routePathToObject(RoutePath path) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("length", path.length);

        ArrayList<Object> points = new ArrayList<>();
        for (int i = 0; i < path.points.size(); i++) {
            points.add(locationPointToObject(path.points.get(i)));
        }
        data.put("points", points);


        ArrayList<Object> events = new ArrayList<>();
        for (int i = 0; i < path.events.size(); i++) {
            events.add(eventToObject(path.events.get(i)));
        }
        data.put("events", events);

        return data;
    }

    static Object eventToObject(RouteEvent event) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("length", event.value);
        data.put("type", event.type);
        data.put("distance", event.distance);

        return data;
    }

    static Object zoneToObject(Zone zone) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("alias", zone.alias);
        data.put("color", zone.color);
        data.put("id", zone.id);
        data.put("location", zone.location);
        data.put("name", zone.name);
        data.put("subLocation", zone.subLocation);

        ArrayList<Object> points = new ArrayList<>();
        for (int i = 0; i < zone.points.size(); i++) {
            points.add(locationPointToObject(zone.points.get(i)));
        }

        data.put("points", points);

        return data;
    }

    static Object locationPointToObject(LocationPoint lp) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("location", lp.location);
        data.put("subLocation", lp.subLocation);
        data.put("y", lp.y);
        data.put("x", lp.x);

        return data;
    }

    static Object locationToObject(Location location) {

        Map<String, Object> data = new HashMap<>(1);
        data.put("id", location.id);
        data.put("name", location.name);
        data.put("description", location.description);
        data.put("version", location.version);

        ArrayList<Object> subLocations = new ArrayList<>();
        for (int i = 0; i < location.subLocations.size(); i++) {
            subLocations.add(subLocationToObject(location.subLocations.get(i)));
        }

        data.put("subLocations", subLocations);


        ArrayList<Object> categories = new ArrayList<>();
        for (int i = 0; i < location.categories.size(); i++) {
            categories.add(categoryToObject(location.categories.get(i)));
        }
        data.put("categories", categories);


        return data;
    }

    private static Object categoryToObject(Venue.Category category) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("id", category.id);
        data.put("name", category.name);
        return data;
    }

    static byte[] bitmapToByteArray(Bitmap bitmap) {
        ByteArrayOutputStream stream = new ByteArrayOutputStream();
        bitmap.compress(Bitmap.CompressFormat.PNG, 100, stream);
        byte[] byteArray = stream.toByteArray();
        bitmap.recycle();
        return byteArray;
    }

    private static Object subLocationToObject(SubLocation subLocation) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("id", subLocation.id);
        data.put("location", subLocation.location);
        data.put("name", subLocation.name);
        data.put("svgFile", subLocation.svgFile);
        data.put("pngFile", subLocation.pngFile);
        data.put("jpgFile", subLocation.jpgFile);
        data.put("width", subLocation.width);
        data.put("height", subLocation.height);
        data.put("azimuth", subLocation.azimuth);
        data.put("latitude", subLocation.latitude);
        data.put("longitude", subLocation.longitude);
        data.put("image", bitmapToByteArray(subLocation.getBitmap()));


        ArrayList<Object> zones = new ArrayList<>();
        for (int i = 0; i < subLocation.zones.size(); i++) {
            zones.add(zoneToObject(subLocation.zones.get(i)));
        }
        data.put("zones", zones);


        ArrayList<Object> venues = new ArrayList<>();
        for (int i = 0; i < subLocation.venues.size(); i++) {
            venues.add(venueToObject(subLocation.venues.get(i)));
        }
        data.put("venues", venues);


        ArrayList<Object> beacons = new ArrayList<>();
        for (int i = 0; i < subLocation.beacons.size(); i++) {
            beacons.add(beaconToObject(subLocation.beacons.get(i)));
        }
        data.put("beacons", beacons);


        ArrayList<Object> measureList = new ArrayList<>();
        for (int i = 0; i < subLocation.measureList.size(); i++) {
            measureList.add(measureToObject(subLocation.measureList.get(i)));
        }
        data.put("measureList", measureList);


        return data;
    }

    private static Object measureToObject(MeasureObject measureObject) {

        Map<String, Object> data = new HashMap<>(1);
        data.put("id", measureObject.id);
        data.put("name", measureObject.name);
        data.put("uuid", measureObject.uuid);
        data.put("type", measureObject.type);
        data.put("status", measureObject.status);
        data.put("quality", measureObject.quality);
        data.put("major", measureObject.major);
        data.put("minor", measureObject.minor);
        data.put("power", measureObject.power);
        data.put("location", measureObject.location);
        data.put("subLocation", measureObject.subLocation);
        data.put("kx", measureObject.kx);
        data.put("ky", measureObject.ky);
        data.put("timeLabel", measureObject.timeLabel);
        data.put("duration", measureObject.duration);
        data.put("entries", measureObject.entries);

        return data;
    }

    private static Object beaconToObject(Beacon beacon) {
        Map<String, Object> data = new HashMap<>(1);

        data.put("id", beacon.id);
        data.put("location", beacon.location);
        data.put("subLocation", beacon.subLocation);
        data.put("major", beacon.major);
        data.put("minor", beacon.minor);
        data.put("uuid", beacon.uuid);
        data.put("name", beacon.name);
        data.put("power", beacon.power);
        data.put("x", beacon.x);
        data.put("y", beacon.y);
        return data;
    }

    private static Object venueToObject(Venue venue) {
        Map<String, Object> data = new HashMap<>(1);

        data.put("id", venue.id);
        data.put("location", venue.location);
        data.put("subLocation", venue.subLocation);
        data.put("x", venue.x);
        data.put("y", venue.y);
        data.put("name", venue.name);
        data.put("alias", venue.alias);
        data.put("phone", venue.phone);
        data.put("image", venue.image);
        data.put("description", venue.description);

        return data;
    }

    static LocationPoint objectToLocationPoint(Map<String, Object> locationPoint) {
        LocationPoint point = new LocationPoint();
        point.x = (float) ((double) locationPoint.get("x"));
        point.y = (float) ((double) locationPoint.get("y"));
        point.location = (int) locationPoint.get("location");
        point.subLocation = (int) locationPoint.get("subLocation");
        return point;
    }
}

==> navigine_sdk-1.2.4%2B3.tar.gz: android/src/main/java/com/navigine/navigine/Convert.java <==
package com.navigine.navigine;

import android.graphics.Bitmap;

import com.navigine.naviginesdk.Beacon;
import com.navigine.naviginesdk.DeviceInfo;
import com.navigine.naviginesdk.Location;
import com.navigine.naviginesdk.LocationPoint;
import com.navigine.naviginesdk.MeasureObject;
import com.navigine.naviginesdk.NavigineNotification;
import com.navigine.naviginesdk.RouteEvent;
import com.navigine.naviginesdk.RoutePath;
import com.navigine.naviginesdk.SubLocation;
import com.navigine.naviginesdk.Venue;
import com.navigine.naviginesdk.Zone;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

class Convert {

    static Object deviceInfoToObject(DeviceInfo deviceInfo) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("azimuth", deviceInfo.azimuth);
        data.put("errorCode", deviceInfo.errorCode);
        data.put("id", deviceInfo.id);
        data.put("location", deviceInfo.location);
        data.put("r", deviceInfo.r);
        data.put("stepCount", deviceInfo.stepCount);
        data.put("subLocation", deviceInfo.subLocation);
        data.put("stepLength", deviceInfo.stepLength);
        data.put("time", deviceInfo.time);
        data.put("x", deviceInfo.x);
        data.put("y", deviceInfo.y);

        ArrayList<Object> zones = new ArrayList<>();
        for (int i = 0; i < deviceInfo.zones.size(); i++) {
            zones.add(zoneToObject(deviceInfo.zones.get(i)));
        }
        data.put("zones", zones);

        ArrayList<Object> paths = new ArrayList<>();
        for (int i = 0; i < deviceInfo.paths.size(); i++) {
            paths.add(routePathToObject(deviceInfo.paths.get(i)));
        }
        data.put("paths", paths);

        return data;
    }

    static Object routePathToObject(RoutePath path) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("length", path.length);

        ArrayList<Object> points = new ArrayList<>();
        for (int i = 0; i < path.points.size(); i++) {
            points.add(locationPointToObject(path.points.get(i)));
        }
        data.put("points", points);


        ArrayList<Object> events = new ArrayList<>();
        for (int i = 0; i < path.events.size(); i++) {
            events.add(eventToObject(path.events.get(i)));
        }
        data.put("events", events);

        return data;
    }

    static Object eventToObject(RouteEvent event) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("length", event.value);
        data.put("type", event.type);
        data.put("distance", event.distance);

        return data;
    }

    static Object zoneToObject(Zone zone) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("alias", zone.alias);
        data.put("color", zone.color);
        data.put("id", zone.id);
        data.put("location", zone.location);
        data.put("name", zone.name);
        data.put("subLocation", zone.subLocation);

        ArrayList<Object> points = new ArrayList<>();
        for (int i = 0; i < zone.points.size(); i++) {
            points.add(locationPointToObject(zone.points.get(i)));
        }

        data.put("points", points);

        return data;
    }

    static Object locationPointToObject(LocationPoint lp) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("location", lp.location);
        data.put("subLocation", lp.subLocation);
        data.put("y", lp.y);
        data.put("x", lp.x);

        return data;
    }

    static Object locationToObject(Location location) {

        Map<String, Object> data = new HashMap<>(1);
        data.put("id", location.id);
        data.put("name", location.name);
        data.put("description", location.description);
        data.put("version", location.version);

        ArrayList<Object> subLocations = new ArrayList<>();
        for (int i = 0; i < location.subLocations.size(); i++) {
            subLocations.add(subLocationToObject(location.subLocations.get(i)));
        }

        data.put("subLocations", subLocations);


        ArrayList<Object> categories = new ArrayList<>();
        for (int i = 0; i < location.categories.size(); i++) {
            categories.add(categoryToObject(location.categories.get(i)));
        }
        data.put("categories", categories);


        return data;
    }

    private static Object categoryToObject(Venue.Category category) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("id", category.id);
        data.put("name", category.name);
        return data;
    }

    static byte[] bitmapToByteArray(Bitmap bitmap) {
        ByteArrayOutputStream stream = new ByteArrayOutputStream();
        bitmap.compress(Bitmap.CompressFormat.PNG, 100, stream);
        byte[] byteArray = stream.toByteArray();
        bitmap.recycle();
        return byteArray;
    }

    private static Object subLocationToObject(SubLocation subLocation) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("id", subLocation.id);
        data.put("location", subLocation.location);
        data.put("name", subLocation.name);
        data.put("svgFile", subLocation.svgFile);
        data.put("pngFile", subLocation.pngFile);
        data.put("jpgFile", subLocation.jpgFile);
        data.put("width", subLocation.width);
        data.put("height", subLocation.height);
        data.put("azimuth", subLocation.azimuth);
        data.put("latitude", subLocation.latitude);
        data.put("longitude", subLocation.longitude);

        ArrayList<Object> zones = new ArrayList<>();
        for (int i = 0; i < subLocation.zones.size(); i++) {
            zones.add(zoneToObject(subLocation.zones.get(i)));
        }
        data.put("zones", zones);


        ArrayList<Object> venues = new ArrayList<>();
        for (int i = 0; i < subLocation.venues.size(); i++) {
            venues.add(venueToObject(subLocation.venues.get(i)));
        }
        data.put("venues", venues);


        ArrayList<Object> beacons = new ArrayList<>();
        for (int i = 0; i < subLocation.beacons.size(); i++) {
            beacons.add(beaconToObject(subLocation.beacons.get(i)));
        }
        data.put("beacons", beacons);


        ArrayList<Object> measureList = new ArrayList<>();
        for (int i = 0; i < subLocation.measureList.size(); i++) {
            measureList.add(measureToObject(subLocation.measureList.get(i)));
        }
        data.put("measureList", measureList);


        return data;
    }

    private static Object measureToObject(MeasureObject measureObject) {

        Map<String, Object> data = new HashMap<>(1);
        data.put("id", measureObject.id);
        data.put("name", measureObject.name);
        data.put("uuid", measureObject.uuid);
        data.put("type", measureObject.type);
        data.put("status", measureObject.status);
        data.put("quality", measureObject.quality);
        data.put("major", measureObject.major);
        data.put("minor", measureObject.minor);
        data.put("power", measureObject.power);
        data.put("location", measureObject.location);
        data.put("subLocation", measureObject.subLocation);
        data.put("kx", measureObject.kx);
        data.put("ky", measureObject.ky);
        data.put("timeLabel", measureObject.timeLabel);
        data.put("duration", measureObject.duration);
        data.put("entries", measureObject.entries);

        return data;
    }

    private static Object beaconToObject(Beacon beacon) {
        Map<String, Object> data = new HashMap<>(1);

        data.put("id", beacon.id);
        data.put("location", beacon.location);
        data.put("subLocation", beacon.subLocation);
        data.put("major", beacon.major);
        data.put("minor", beacon.minor);
        data.put("uuid", beacon.uuid);
        data.put("name", beacon.name);
        data.put("power", beacon.power);
        data.put("x", beacon.x);
        data.put("y", beacon.y);
        return data;
    }

    private static Object venueToObject(Venue venue) {
        Map<String, Object> data = new HashMap<>(1);

        data.put("id", venue.id);
        data.put("location", venue.location);
        data.put("subLocation", venue.subLocation);
        data.put("x", venue.x);
        data.put("y", venue.y);
        data.put("name", venue.name);
        data.put("alias", venue.alias);
        data.put("phone", venue.phone);
        data.put("description", venue.description);

        return data;
    }

    static LocationPoint objectToLocationPoint(Map<String, Object> locationPoint) {
        LocationPoint point = new LocationPoint();
        point.x = (float) ((double) locationPoint.get("x"));
        point.y = (float) ((double) locationPoint.get("y"));
        point.location = (int) locationPoint.get("location");
        point.subLocation = (int) locationPoint.get("subLocation");
        return point;
    }

    public static Object notificationToObject(NavigineNotification notification) {
        Map<String, Object> data = new HashMap<>(1);
        data.put("id", notification.id);
        data.put("content", notification.content);
        data.put("imagePath", notification.imagePath);
        data.put("imageUrl", notification.imageUrl);
        data.put("title", notification.title);
        return data;
    }
}
